@@ -38,6 +38,9 @@ def main():
 def dovado(
     ctx: typer.Context,
     # Arguments
+    # file_path is used through the context in cli_utility during parameters validation
+    # and is then passed through context
+    # until it reaches this method where it is extracted and used as parsed_src
     file_path: Path = typer.Option(  # pylint: disable=unused-argument
         ...,
         exists=True,
@@ -49,8 +52,6 @@ def dovado(
             + " for the directory structure your RTL project should comply with"
         ),
     ),
-    # file_path is used through the context in cli_utility during parameters validation and is then passed through context
-    # until it reaches this method where it is extracted and used as parsed_src
     # Required Cli options
     board: str = typer.Option(
         ...,
@@ -242,26 +243,26 @@ def space(
     approximate: bool = typer.Option(
         False, help="enable approximations for fitness function"
     ),
-    fitness_estimator: str = typer.Option(
-        "KERNEL_RIDGE",
-        callback=validate_estimator,
-        help="estimator to use for fitness function approximation,"
-        + "'kernel_ridge' is default. 'stream_learning_isoup' selects a ISOUP Adaptive Tree Regressor trained incrementally "
-        + "while 'stream_learning_stacked' selects a Stacked tree regressor",
-    ),
-    test_estimation: bool = typer.Option(
-        False,
-        help="record all estimated values along with the real "
-        + "computed values (slows down computation a lot)",
-    ),
-    record_design_values: bool = typer.Option(
-        False, help="record all design values in a csv file"
-    ),
-    read_design_values: bool = typer.Option(
-        False,
-        help="read design values from a csv file recorded with "
-        + "the --record-design-values flag",
-    ),
+    #fitness_estimator: str = typer.Option(
+    #    "",
+    #    callback=validate_estimator,
+    #    help="estimator to use for fitness function approximation,"
+    #    + "'kernel_ridge' is default. 'stream_learning_isoup' selects a ISOUP Adaptive Tree Regressor trained incrementally "
+    #    + "while 'stream_learning_stacked' selects a Stacked tree regressor",
+    #),
+    #test_estimation: bool = typer.Option(
+    #    False,
+    #    help="record all estimated values along with the real "
+    #    + "computed values (slows down computation a lot)",
+    #),
+    #record_design_values: bool = typer.Option(
+    #    False, help="record all design values in a csv file"
+    #),
+    #read_design_values: bool = typer.Option(
+    #    False,
+    #    help="read design values from a csv file recorded with "
+    #    + "the --record-design-values flag",
+    #),
 ):
     """
     RTL design space exploration
